@@ -1,5 +1,5 @@
 /* Build symbol tables in GDB's internal format.
-   Copyright (C) 1986-2023 Free Software Foundation, Inc.
+   Copyright (C) 1986-2025 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -16,8 +16,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#if !defined (BUILDSYM_H)
-#define BUILDSYM_H 1
+#ifndef GDB_BUILDSYM_H
+#define GDB_BUILDSYM_H
 
 #include "gdbsupport/gdb_obstack.h"
 #include "symtab.h"
@@ -25,7 +25,6 @@
 
 struct objfile;
 struct symbol;
-struct addrmap;
 struct compunit_symtab;
 enum language;
 
@@ -56,7 +55,7 @@ struct subfile
   struct subfile *next = nullptr;
   std::string name;
 
-  /* This field is analoguous in function to symtab::filename_for_id.
+  /* This field is analogous in function to symtab::filename_for_id.
 
      It is used to look up existing subfiles in calls to start_subfile.  */
   std::string name_for_id;
@@ -131,6 +130,10 @@ enum linetable_entry_flag : unsigned
   /* Indicates this PC is a good location to place a breakpoint at the first
      instruction past a function prologue.  */
   LEF_PROLOGUE_END = 1 << 2,
+
+  /* Indicated that this PC is part of the epilogue of a function, making
+     software watchpoints unreliable.  */
+  LEF_EPILOGUE_BEGIN = 1 << 3,
 };
 DEF_ENUM_FLAGS_TYPE (enum linetable_entry_flag, linetable_entry_flags);
 
@@ -284,11 +287,6 @@ struct buildsym_compunit
     return &m_context_stack.back ();
   }
 
-  int get_context_stack_depth () const
-  {
-    return m_context_stack.size ();
-  }
-
   struct subfile *get_current_subfile ()
   {
     return m_current_subfile;
@@ -324,10 +322,10 @@ struct buildsym_compunit
   struct context_stack pop_context ();
 
   struct block *end_compunit_symtab_get_static_block
-    (CORE_ADDR end_addr, int expandable, int required);
+    (CORE_ADDR end_addr, bool expandable, bool required);
 
   struct compunit_symtab *end_compunit_symtab_from_static_block
-    (struct block *static_block, int expandable);
+    (struct block *static_block, bool expandable);
 
   struct compunit_symtab *end_compunit_symtab (CORE_ADDR end_addr);
 
@@ -344,15 +342,12 @@ private:
 				       struct pending_block *old_blocks,
 				       const struct dynamic_prop *static_link,
 				       CORE_ADDR start, CORE_ADDR end,
-				       int is_global, int expandable);
+				       bool is_global, bool expandable);
 
-  struct blockvector *make_blockvector ();
+  std::unique_ptr<blockvector> make_blockvector ();
 
   void watch_main_source_file_lossage ();
 
-  struct compunit_symtab *end_compunit_symtab_with_blockvector
-    (struct block *static_block, int expandable);
-
   /* The objfile we're reading debug info from.  */
   struct objfile *m_objfile;
 
@@ -381,8 +376,11 @@ private:
      the same lifetime as objfile.  */
   const char *m_debugformat = nullptr;
 
-  /* The compunit we are building.  */
-  struct compunit_symtab *m_compunit_symtab = nullptr;
+  /* The compunit we are building.  If the symtab is owned by this
+     object, both fields are set.  For a re-opened symtab, only
+     m_compunit_symtab is set.  */
+  std::unique_ptr<compunit_symtab> m_owned_compunit_symtab;
+  compunit_symtab *m_compunit_symtab;
 
   /* Language of this compunit_symtab.  */
   enum language m_language;
@@ -445,7 +443,7 @@ private:
   struct pending *m_local_symbols = nullptr;
 };
 
-
+using buildsym_compunit_up = std::unique_ptr<buildsym_compunit>;
 
 extern void add_symbol_to_list (struct symbol *symbol,
 				struct pending **listhead);
@@ -453,4 +451,4 @@ extern void add_symbol_to_list (struct symbol *symbol,
 extern struct symbol *find_symbol_in_list (struct pending *list,
 					   char *name, int length);
 
-#endif /* defined (BUILDSYM_H) */
+#endif /* GDB_BUILDSYM_H */
