@@ -15,11 +15,13 @@
 
 import sys
 
+import gdb
+
 # Avoid generating
 # src/gdb/testsuite/gdb.python/__pycache__/gdb_leak_detector.cpython-<n>.pyc.
 sys.dont_write_bytecode = True
 
-import gdb_leak_detector
+import gdb_leak_detector  # noqa: E402
 
 
 class read_leak_detector(gdb_leak_detector.gdb_leak_detector):
